multidim.SimplicialComplex.from_distances — GDA Toolbox v1.0 Manual

# multidim.SimplicialComplex.from_distances

classmethod `SimplicialComplex.` `from_distances`(dists, max_length=-1.0, points=None)

  Construct a `SimplicialComplex` from a symmetric matrix of distances.

  Parameters: | dists : `numpy.ndarray` An N-by-N symmetric array, with 0s on the diagonal, as obtained from `scipy.spatial.distances.squareform()` max_length : float If `max_length >= 0`, store only those edges of length less than `max_length`. Default: -1, store all edges. points : `pandas.DataFrame` A fully-formed DataFrame of point information for stratum[0]. But, if you have that info, you probably want to use `PointCloud` instead.
  Returns: | `SimplicialComplex`

#### Previous topic

multidim.SimplicialComplex.check

#### Next topic

multidim.SimplicialComplex.make_pers0